﻿

local moduleName = "HealthBarText"



----------------------------
--      Localization      --
----------------------------

local L = AceLibrary("AceLocale-2.2"):new("BunchOfBars"..moduleName)

L:RegisterTranslations("enUS", function() return {
	[moduleName] = "Health Bar Text",

	["Text Format"] = true,

	["Predefined Formats"] = true,
	["Choose from a set of prefedined formats."] = true,

	["Text Justification"] = true,
	["Set the horizontal text justification."] = true
} end)

L:RegisterTranslations("koKR", function() return {
	[moduleName] = "생명력 바 글자",

	["Text Format"] = "글자 설정",

	["Predefined Formats"] = "정의된 설정",
	["Choose from a set of prefedined formats."] = "미리 만들어진 설정을 사용합니다.",

	["Text Justification"] = "글자 정의",
	["Set the horizontal text justification."] = "표시하고 싶은 글자를 입력합니다."
} end)


----------------------------------
--      Local Declaration      --
----------------------------------

local DogTag = AceLibrary("DogTag-1.0")

local formats = {
	["[HasDivineIntervention:[Dead?IsFeignedDeath:HasSoulstone:Dead]]"]                                                              = "'Dead/Feigned/...'",
	["[[HasDivineIntervention:[Dead?IsFeignedDeath:HasSoulstone:Dead]]:[IsMouseOver?Text([MissingHP:Negate:Red] | [CurHP:Green])]]"] = "'Dead/Feigned/...' or 'Health status' on mouseover",
	["[IsMouseOver?Text([MissingHP:Negate:Red] | [CurHP:Green])]"]                                                                   = "'Health status' on mouseover",
	["[IsMana?[~AFK?[~Dead?PercentMP:Blue]]]"]                                                                                       = "'Mana %' while not Dead or AFK",
	["[[AFK:Offline]?Name:Trunc(6):Gray!Name:Trunc(6):ClassColor] [IsMana?[~AFK?[~Dead?PercentMP:Blue:Bracket]]]"]                   = "'Status colored Name' followed by 'Mana %' while not Dead or AFK"
}

local formatsdesc = { }
do
	for k in pairs(formats) do
		formatsdesc[k] = k
	end
end


----------------------------------
--      Module Declaration      --
----------------------------------

local plugin = BunchOfBars:NewModule(moduleName, "AceEvent-2.0")

plugin.revision = tonumber(("$Revision: 39557 $"):match("%d+"))

plugin.options = {
	name = L[moduleName],
	args = {
		format = {
			type  = "text",
			name  = L["Text Format"],
			desc  = L["Text Format"],
			usage = "DogTag-1.0 tags. See http://www.wowace.com/wiki/DogTag-1.0",
			get   = "GetSetFormat",
			set   = "GetSetFormat"
		},
		preformats = {
			type  = "text",
			name  = L["Predefined Formats"],
			desc  = L["Choose from a set of prefedined formats."],
			usage = "",
			validate     = formats,
			validateDesc = formatsdesc,
			get = "GetSetFormat",
			set = "GetSetFormat"
		},
		justification = {
			type     = "text",
			name     = L["Text Justification"],
			desc     = L["Set the horizontal text justification."],
			usage    = "",
			validate = { "LEFT", "CENTER", "RIGHT" },
			get      = "GetSetTextJustification",
			set      = "GetSetTextJustification"
		},
	}
}

plugin.defaultDB = {
	format        = next(formats),
	justification = "CENTER"
}



----------------------------------
--      Module Functions        --
----------------------------------

function plugin:OnEnable()
	self:RegisterEvent("UNIT_MAXHEALTH")
end


function plugin:OnCreate(frame)
	local bar  = frame.parts["HealthBar"]
	local font = bar:CreateFontString(nil, "OVERLAY")
	font:SetFontObject(GameFontHighlightSmall)
	font:SetVertexColor(1, 1, 1, 1)
	font:ClearAllPoints()
	font:SetPoint("BOTTOMLEFT", bar, "BOTTOMLEFT", 2, 0)
	font:SetPoint("TOPRIGHT", bar, "TOPRIGHT", -2, 0)
	font:Show()

	return font
end


function plugin:OnUpdate(frame, font)
	font:SetJustifyH(self.db.profile.justification)

	DogTag:RegisterFontString(font, frame, frame.unit, self.db.profile.format)
end


function plugin:OnInactive(frame, mypart)
	DogTag:UnregisterFontString(mypart)
end


-- stupix fix for removing the "Dead" of just resurrected people, only works if they recieve a buff that boosts their hp
function plugin:UNIT_MAXHEALTH(unit)
	if self.core.frames[unit] then
		DogTag:UpdateFontString(self.core.frames[unit].parts[self.name])
	end
end


function plugin:GetSetFormat(v)
	if type(v) == "nil" then return self.db.profile.format end

	-- this check is to assure we don't reschedule the event to often
	if self.db.profile.format ~= v then
		self.db.profile.format = v

		self:UpdateAll()
	end
end


function plugin:GetSetTextJustification(v)
	if type(v) == "nil" then return self.db.profile.justification end

	-- this check is to assure we don't reschedule the event to often
	if self.db.profile.justification ~= v then
		self.db.profile.justification = v

		self:UpdateAll()
	end
end
